@@ -1,9 +1,19 @@
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 """ Tests for the trait change event tracer. """
 
-from traits.api import Float, HasTraits, on_trait_change
-from traits.testing.unittest_tools import unittest
+import unittest
 
 from traits import trait_notifiers
+from traits.api import Float, HasTraits, on_trait_change
 
 
 class FuzException(Exception):
@@ -146,7 +156,3 @@ class TestChangeEventTracers(unittest.TestCase):
         self.assertEqual(self.exceptions[2].args, ("method",))
         self.assertIsInstance(self.exceptions[3], FuzException)
         self.assertEqual(self.exceptions[3].args, ("function",))
-
-
-if __name__ == "__main__":
-    unittest.main()
